==> iqpnni-3.2.tar.gz: iqpnni-3.2/src/main.cpp <==
/***************************************************************************
                          main.cpp  -  description
                             -------------------
    begin                : Fri Apr 11 10:08:35 CEST 2003
    copyright            : (C) 2003 by
    email                : vinh@cs.uni-duesseldorf.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdlib.h>

#include "constant.h"
#include "utl.h"
#include "vec.h"
#include "mat.h"
#include "cube.h"
#include "seq.h"
#include "ali.h"
#include "ptn.h"
#include "ptnls.h"
#include "brent.h"
#include "exnd.h"
#include "exndarr.h"
#include "innd.h"
#include "inndarr.h"
#include "br.h"
#include "brarr.h"
#include "basem.h"
#include "model.h"
#include "optpairseq.h"
#include "rate.h"
#include "opturtree.h"
#include "urtree.h"
#include "outstream.h"
#include "testmethod.h"
#include "bionj.h"
#include "interface.h"
#include "rannum.h"
#include "tn93m.h"

#ifdef PARALLEL
#	include <mpi.h>
#endif // PARALLEL

int isContinuous = 0;




void init () {
	opt_urtree.doConstructor ();
	opt_pairseq.doConstructor ();
	alignment.doConstructor ();
	ptnlist.doConstructor ();
	createPosGenChar ();
}


//overload the operator <<
std::ostream &operator << (std::ostream &out, Vec<char> &vec) {
	return OutStream::write (vec, out);
}

//overload the operator <<
std::ofstream &operator << (std::ofstream &out, Vec<char> &vec) {

	return OutStream::write (vec, out);
}

#ifdef PARALLEL
int mpi_myrank;
int mpi_size;
int mpi_master_rank = 0;

long p_randn;
long p_rand;

#endif

void Finalize(int exit_code) {
#pragma pomp inst begin(finalize)
#ifdef PARALLEL
	MPI_Finalize();
#endif
	if (isMasterProc())
		cout << "Finished!!!" << endl;
#pragma pomp inst end(finalize)
	exit(exit_code);
}

int random_seed = -1;

int main(int argc, char *argv[]) {

	#pragma pomp inst init

	#pragma pomp inst begin(main)
	 
#ifdef PARALLEL
	MPI_Init(&argc, &argv);
	MPI_Comm_rank(MPI_COMM_WORLD, &mpi_myrank);
	MPI_Comm_size(MPI_COMM_WORLD, &mpi_size);
	//cout << " Process " << mpi_myrank << " of " << mpi_size << endl;
#endif

	CommonParameters params;

	initializeParams(params);
	
	Interface inter_;


	char aliFileName_[FILENAME_LEN];

	init ();

	char userTreeFileName_[FILENAME_LEN]   = "";

	if (isMasterProc()) {
#ifdef USE_LONG_DOUBLE
		cout << "Use long double (" << sizeof(long double)
			<< ") for numerical operations." << endl;
#else
		//cout << "Use double as numerical operations." << endl;
#endif
	}

	int status_ = inter_.getUserPam (argc, argv, userTreeFileName_, aliFileName_,params);

	if (status_ == 0)
		Finalize(0);

	random_seed = RanNum::initRandom (random_seed);

	if (isMasterProc())
		cout << "Initial seed: " << random_seed << endl;
	
	alignment.convertDataType(params.dataType);


	TestMethod testMethod_;

	testMethod_.create (userTreeFileName_, aliFileName_, params);

	#pragma pomp inst end(main)
	Finalize(EXIT_SUCCESS);
	return 0;
}

==> iqpnni-3.3.1.tar.gz: iqpnni-3.3.1/src/main.cpp <==
/***************************************************************************
                          main.cpp  -  description
                             -------------------
    begin                : Fri Apr 11 10:08:35 CEST 2003
    copyright            : (C) 2003 by
    email                : vinh@cs.uni-duesseldorf.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdlib.h>

#include "constant.h"
#include "utl.h"
#include "vec.h"
#include "mat.h"
#include "cube.h"
#include "seq.h"
#include "ali.h"
#include "ptn.h"
#include "ptnls.h"
#include "brent.h"
#include "exnd.h"
#include "exndarr.h"
#include "innd.h"
#include "inndarr.h"
#include "br.h"
#include "brarr.h"
#include "basem.h"
#include "model.h"
#include "optpairseq.h"
#include "rate.h"
#include "opturtree.h"
#include "urtree.h"
#include "outstream.h"
#include "testmethod.h"
#include "bionj.h"
#include "interface.h"
#include "tn93m.h"

#ifdef PARALLEL
#	include <mpi.h>
#endif // PARALLEL

int isContinuous = 0;




void init () {
	opt_urtree.doConstructor ();
	opt_pairseq.doConstructor ();
	alignment.doConstructor ();
	ptnlist.doConstructor ();
	createPosGenChar ();
}


//overload the operator <<
std::ostream &operator << (std::ostream &out, Vec<char> &vec) {
	return OutStream::write (vec, out);
}

//overload the operator <<
std::ofstream &operator << (std::ofstream &out, Vec<char> &vec) {

	return OutStream::write (vec, out);
}

#ifdef PARALLEL
int mpi_myrank;
int mpi_size;
int mpi_master_rank = 0;

long p_randn;
long p_rand;

#endif

void Finalize(int exit_code) {
#ifdef PARALLEL
	MPI_Finalize();
#endif
	if (isMasterProc())
		cout << "Finished!!!" << endl;
	exit(exit_code);
}

//int random_seed = -1;

int main(int argc, char *argv[]) {

#ifdef PARALLEL
	MPI_Init(&argc, &argv);
	MPI_Comm_rank(MPI_COMM_WORLD, &mpi_myrank);
	MPI_Comm_size(MPI_COMM_WORLD, &mpi_size);
	//cout << " Process " << mpi_myrank << " of " << mpi_size << endl;
#endif

	CommonParameters params;
	InputParameters in_pam;

	initializeParams(params);
	initInputParams(in_pam);
	
	Interface inter_;


	//char aliFileName_[FILENAME_LEN] = "";

	init ();

	//char userTreeFileName_[FILENAME_LEN]   = "";

	if (isMasterProc()) {
#ifdef USE_LONG_DOUBLE
		cout << "Use long double (" << sizeof(long double)
			<< ") for numerical operations." << endl;
#else
		//cout << "Use double as numerical operations." << endl;
#endif
	}


	int status_ = inter_.getUserPam (argc, argv, params, in_pam);

	if (status_ == 0)
		Finalize(0);


	//if (isMasterProc())
		//cout << "Initial seed: " << in_pam.random_seed << endl;
	
	alignment.convertDataType(params.dataType);
	opt_urtree.allocMemory();

	TestMethod testMethod_;

	testMethod_.create (params, in_pam);

	Finalize(EXIT_SUCCESS);
	return 0;
}
